Home - Kerasy Documentation
Author: Shuto
Description: Brief explanation of Home and introduction of modules that can be used in Kerasy

# Welcome to Kerasy

Kerasy: The Python Deep Learning library

> "Keras" is a high-level neural networks API, written in Python and capable of running on top of TensorFlow, CNTK, or Theano. It was developed with a focus on enabling fast experimentation. Being able to go from idea to result with the least possible delay is key to doing good research.

Danger

This is not Keras which is well known deep learning framework, so if you want to enjoy deep learning, visit Keras.

## Why I made Kerasy

I study deep learning, and machine learning theory at a University, and have practical experiences in internships, hackathons, and competitions.

Through those experiences, I felt I wanted to go further, next step, building my original model, which is different from the conventional one (NN, CNN, RNN, ..., backpropagation series.)

On the other hand, I thought it is extremely important to understand the conventional one properly, so by building the framework on my own, I try confirming my understanding of them.

As it is too hard to build a deep learning framework from scratch, I decided to imitate Keras, one of the most popular frameworks.

## Future prospects

I am particularly interested in "synthetic biology" (redesigning, or remodeling organisms by engineering them to have new abilities) and "neuroscience" (Back-engineering the flexibility of brain structure concerned with mechanism of memory, pattern recognition, and so on). Therefore, I want to study deeply about them and apply them for Human augmentation purpose to create the more wonderful world.

Next »